@@ -54,10 +54,17 @@ class Rocket():
             raise ValueError("No FireWorks are ready to run and match query! {}".format(self.fworker.query))
 
         if '_launch_dir' in m_fw.spec:
+            prev_dir = launch_dir
             os.chdir(m_fw.spec['_launch_dir'])
             launch_dir = os.path.abspath(os.getcwd())
             lp._change_launch_dir(launch_id, launch_dir)
 
+            if not os.listdir(prev_dir) and FWConfig().REMOVE_USELESS_DIRS:
+                try:
+                    os.rmdir(prev_dir)
+                except:
+                    pass
+
         # write FW.json and/or FW.yaml to the directory
         if FWConfig().PRINT_FW_JSON:
             m_fw.to_file('FW.json', indent=4)
